@@ -1,6 +1,6 @@
 # file openpyxl/__init__.py
 
-# Copyright (c) 2010 openpyxl
+# Copyright (c) 2010-2011 openpyxl
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,7 +21,7 @@
 # THE SOFTWARE.
 #
 # @license: http://www.opensource.org/licenses/mit-license.php
-# @author: Eric Gazoni
+# @author: see AUTHORS file
 
 """Imports for the openpyxl package."""
 
@@ -35,11 +35,15 @@ from openpyxl import reader
 from openpyxl import shared
 from openpyxl import writer
 
+# shortcuts
+from openpyxl.workbook import Workbook
+from openpyxl.reader.excel import load_workbook
+
 # constants
 
 __major__ = 1  # for major interface/format changes
 __minor__ = 5  # for minor interface/format changes
-__release__ = 5  # for tweaks, bug-fixes, or development
+__release__ = 7  # for tweaks, bug-fixes, or development
 
 __version__ = '%d.%d.%d' % (__major__, __minor__, __release__)
 
