@@ -1,6 +1,6 @@
 # file openpyxl/reader/excel.py
 
-# Copyright (c) 2010 openpyxl
+# Copyright (c) 2010-2011 openpyxl
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,7 +21,7 @@
 # THE SOFTWARE.
 #
 # @license: http://www.opensource.org/licenses/mit-license.php
-# @author: Eric Gazoni
+# @author: see AUTHORS file
 
 """Read an xlsx file into Python"""
 
@@ -36,25 +36,25 @@ from openpyxl.workbook import Workbook, DocumentProperties
 from openpyxl.reader.strings import read_string_table
 from openpyxl.reader.style import read_style_table
 from openpyxl.reader.workbook import read_sheets_titles, read_named_ranges, \
-        read_properties_core, get_sheet_ids
+        read_properties_core, get_sheet_ids, read_excel_base_date
 from openpyxl.reader.worksheet import read_worksheet
 from openpyxl.reader.iter_worksheet import unpack_worksheet
 
-def load_workbook(filename, use_iterators = False):
+def load_workbook(filename, use_iterators=False):
     """Open the given filename and return the workbook
 
     :param filename: the path to open
     :type filename: string
-    
+
     :param use_iterators: use lazy load for cells
     :type use_iterators: bool
 
     :rtype: :class:`openpyxl.workbook.Workbook`
-    
+
     .. note::
-        
+
         When using lazy load, all worksheets will be :class:`openpyxl.reader.iter_worksheet.IterableWorksheet`
-        and the returned workbook will be read-only. 
+        and the returned workbook will be read-only.
 
     """
 
@@ -77,8 +77,8 @@ def load_workbook(filename, use_iterators = False):
         _load_workbook(wb, archive, filename, use_iterators)
     except KeyError, e:
         raise InvalidFileException(unicode(e))
-    finally:
-        archive.close()
+
+    archive.close()
     return wb
 
 def _load_workbook(wb, archive, filename, use_iterators):
@@ -90,13 +90,15 @@ def _load_workbook(wb, archive, filename, use_iterators):
         wb.properties = read_properties_core(archive.read(ARC_CORE))
     except KeyError:
         wb.properties = DocumentProperties()
-    
+
     try:
         string_table = read_string_table(archive.read(ARC_SHARED_STRINGS))
     except KeyError:
         string_table = {}
     style_table = read_style_table(archive.read(ARC_STYLE))
 
+    wb.properties.excel_base_date = read_excel_base_date(xml_source = archive.read(ARC_WORKBOOK))
+
     # get worksheets
     wb.worksheets = []  # remove preset worksheet
     sheet_names = read_sheets_titles(archive.read(ARC_WORKBOOK))
@@ -113,7 +115,6 @@ def _load_workbook(wb, archive, filename, use_iterators):
         else:
             xml_source = unpack_worksheet(archive, worksheet_path)
             new_ws = read_worksheet(xml_source, wb, sheet_name, string_table, style_table, filename, sheet_codename)
-            #new_ws = read_worksheet(archive.read(worksheet_path), wb, sheet_name, string_table, style_table, filename, sheet_codename)
-        wb.add_sheet(new_ws, index = i)
+        wb.add_sheet(new_ws, index=i)
 
     wb._named_ranges = read_named_ranges(archive.read(ARC_WORKBOOK), wb)
