@@ -1,6 +1,6 @@
 # file openpyxl/reader/workbook.py
 
-# Copyright (c) 2010 openpyxl
+# Copyright (c) 2010-2011 openpyxl
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,7 +21,7 @@
 # THE SOFTWARE.
 #
 # @license: http://www.opensource.org/licenses/mit-license.php
-# @author: Eric Gazoni
+# @author: see AUTHORS file
 
 """Read in global settings to be maintained by the workbook object."""
 
@@ -29,7 +29,7 @@
 from openpyxl.shared.xmltools import fromstring, QName
 from openpyxl.shared.ooxml import NAMESPACES
 from openpyxl.workbook import DocumentProperties
-from openpyxl.shared.date_time import W3CDTF_to_datetime
+from openpyxl.shared.date_time import W3CDTF_to_datetime,CALENDAR_WINDOWS_1900,CALENDAR_MAC_1904
 from openpyxl.namedrange import NamedRange, NamedRangeContainingValue, split_named_range, refers_to_range
 
 import datetime
@@ -76,6 +76,15 @@ def read_properties_core(xml_source):
     return properties
 
 
+def read_excel_base_date(xml_source):
+    root = fromstring(text = xml_source)
+    wbPr = root.find(QName('http://schemas.openxmlformats.org/spreadsheetml/2006/main', 'workbookPr').text)
+    if ('date1904' in wbPr.keys() and wbPr.attrib['date1904'] in ('1', 'true')):
+        return CALENDAR_MAC_1904
+
+    return CALENDAR_WINDOWS_1900
+
+
 def read_sheets_titles(xml_source):
     """Read titles for all sheets."""
     root = fromstring(xml_source)
