@@ -1,6 +1,6 @@
 # file openpyxl/worksheet.py
 
-# Copyright (c) 2010 openpyxl
+# Copyright (c) 2010-2011 openpyxl
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,7 +21,7 @@
 # THE SOFTWARE.
 #
 # @license: http://www.opensource.org/licenses/mit-license.php
-# @author: Eric Gazoni
+# @author: see AUTHORS file
 
 """Worksheet is the 2nd-level container in Excel."""
 
@@ -39,6 +39,7 @@ from openpyxl.shared.password_hasher import hash_password
 from openpyxl.style import Style, DEFAULTS as DEFAULTS_STYLE
 from openpyxl.drawing import Drawing
 from openpyxl.namedrange import NamedRangeContainingValue
+from openpyxl.shared.compat import OrderedDict
 
 _DEFAULTS_STYLE_HASH = hash(DEFAULTS_STYLE)
 
@@ -133,15 +134,23 @@ class ColumnDimension(object):
         self.collapsed = False
         self.style_index = 0
 
-
 class PageMargins(object):
     """Information about page margins for view/print layouts."""
 
-    def __init__(self):
-        self.left = self.right = 0.7
-        self.top = self.bottom = 0.75
-        self.header = self.footer = 0.3
+    valid_margins = ("left", "right", "top", "bottom", "header", "footer")
 
+    def __init__(self):
+        self.left = self.right = self.top = self.bottom = self.header = self.footer = None
+
+    @property
+    def margins(self):
+        margins = OrderedDict()
+        for margin_name in self.valid_margins:
+            margin_value = getattr(self, margin_name)
+            if margin_value:
+                margins[margin_name] = "%0.2f" % margin_value
+
+        return margins
 
 class SheetProtection(object):
     """Information about protection of various aspects of a sheet."""
@@ -199,6 +208,11 @@ class Worksheet(object):
     SHEETSTATE_HIDDEN = 'hidden'
     SHEETSTATE_VERYHIDDEN = 'veryHidden'
 
+    PAPER_SIZE_LETTER = '1'
+    PAPER_SIZE_LEGAL = '5'
+    ORIENTATION_PORTRAIT = 'portrait'
+    ORIENTATION_LANDSCAPE = 'landscape'
+
     def __init__(self, parent_workbook, title='Sheet'):
         self._parent = parent_workbook
         self._title = ''
@@ -228,10 +242,16 @@ class Worksheet(object):
         self.default_column_dimension = ColumnDimension()
         self._auto_filter = None
         self._freeze_panes = None
+        self.paper_size = None
+        self.orientation = None
 
     def __repr__(self):
         return u'<Worksheet "%s">' % self.title
 
+    @property
+    def parent(self):
+        return self._parent
+
     @property
     def encoding(self):
         return self._parent.encoding
@@ -467,6 +487,13 @@ class Worksheet(object):
             self._styles[coordinate] = Style()
         return self._styles[coordinate]
 
+    def set_printer_settings(self, paper_size, orientation):
+        """Set printer settings """
+
+        self.paper_size = paper_size
+        assert orientation in (self.ORIENTATION_PORTRAIT, self.ORIENTATION_LANDSCAPE), "Values should be %s or %s" % (self.ORIENTATION_PORTRAIT, self.ORIENTATION_LANDSCAPE)
+        self.orientation = orientation
+
     def create_relationship(self, rel_type):
         """Add a relationship for this sheet."""
         rel = Relationship(rel_type)
