@@ -1,6 +1,6 @@
 # file openpyxl/writer/straight_worksheet.py
 
-# Copyright (c) 2010 openpyxl
+# Copyright (c) 2010-2011 openpyxl
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,17 +21,14 @@
 # THE SOFTWARE.
 #
 # @license: http://www.opensource.org/licenses/mit-license.php
-# @author: Eric Gazoni
+# @author: see AUTHORS file
 
 """Write worksheets to xml representations in an optimized way"""
 
 import datetime
 import os
 
-try:
-    from collections import OrderedDict
-except ImportError:
-    from openpyxl.writer.odict import OrderedDict
+from openpyxl.shared.compat import OrderedDict
 
 from openpyxl.cell import column_index_from_string, get_column_letter, Cell
 from openpyxl.worksheet import Worksheet
@@ -40,7 +37,8 @@ from openpyxl.shared.xmltools import (XMLGenerator, get_document_content,
 from openpyxl.shared.date_time import SharedDate
 from openpyxl.shared.ooxml import MAX_COLUMN, MAX_ROW
 from openpyxl.shared import NUMERIC_TYPES
-from tempfile import NamedTemporaryFile
+from openpyxl.shared.exc import WorkbookAlreadySaved
+from openpyxl.shared.compat import NamedTemporaryFile
 from openpyxl.writer.excel import ExcelWriter
 from openpyxl.writer.strings import write_string_table
 from openpyxl.writer.styles import StyleWriter
@@ -90,7 +88,12 @@ def get_temporary_file(filename):
 
         return fobj
     else:
+        if filename is None:
+            raise WorkbookAlreadySaved('this workbook has already been saved '
+                    'and cannot be modified or saved anymore.')
+
         fobj = open(filename, 'r+')
+
         DESCRIPTORS_CACHE[filename] = fobj
 
         if len(DESCRIPTORS_CACHE) > DESCRIPTORS_CACHE_SIZE:
@@ -136,6 +139,11 @@ class DumpWorksheet(Worksheet):
                 self._fileobj_header_name,
                 self._fileobj_name)
 
+    def _unset_temp_files(self):
+        self._fileobj_header_name = None
+        self._fileobj_content_name = None
+        self._fileobj_name = None
+
     def write_header(self):
 
         fobj = get_temporary_file(filename=self._fileobj_header_name)
@@ -305,7 +313,9 @@ class ExcelDumpWriter(ExcelWriter):
             sheet.close()
             archive.write(sheet.filename, PACKAGE_WORKSHEETS + '/sheet%d.xml' % (i + 1))
             for filename in sheet._temp_files:
+                del DESCRIPTORS_CACHE[filename]
                 os.remove(filename)
+            sheet._unset_temp_files()
 
 
 class StyleDumpWriter(StyleWriter):
