@@ -29,6 +29,7 @@
 from StringIO import StringIO  # cStringIO doesn't handle unicode
 
 # package imports
+import decimal
 from openpyxl.cell import coordinate_from_string, column_index_from_string
 from openpyxl.shared.xmltools import Element, SubElement, XMLGenerator, \
         get_document_content, start_tag, end_tag, tag
@@ -60,6 +61,14 @@ def write_worksheet(worksheet, string_table, style_table):
     if worksheet.auto_filter:
         tag(doc, 'autoFilter', {'ref': worksheet.auto_filter})
     write_worksheet_hyperlinks(doc, worksheet)
+
+    margins = worksheet.page_margins.margins
+    if margins:
+        tag(doc, 'pageMargins', margins)
+
+    if worksheet.paper_size is not None:        #size and orientation set in common setter, so expect both or neither
+        tag(doc, 'pageSetup', {'paperSize':'%s' % worksheet.paper_size, 'orientation':'%s' % worksheet.orientation})
+
     if worksheet._charts:
         tag(doc, 'drawing', {'r:id':'rId1'})
     end_tag(doc, 'worksheet')
@@ -100,7 +109,7 @@ def write_worksheet_sheetviews(doc, worksheet):
     tag(doc, 'selection', selectionAttrs)
     end_tag(doc, 'sheetView')
     end_tag(doc, 'sheetViews')
-    
+
 
 def write_worksheet_cols(doc, worksheet):
     """Write worksheet columns to xml."""
@@ -149,7 +158,7 @@ def write_worksheet_data(doc, worksheet, string_table, style_table):
             attrs['customHeight'] = '1'
         start_tag(doc, 'row', attrs)
         row_cells = cells_by_row[row_idx]
-        sorted_cells = sorted(row_cells, key = row_sort)
+        sorted_cells = sorted(row_cells, key=row_sort)
         for cell in sorted_cells:
             value = cell._value
             coordinate = cell.get_coordinate()
@@ -162,20 +171,20 @@ def write_worksheet_data(doc, worksheet, string_table, style_table):
             if value is None:
                 tag(doc, 'v', body='')
             elif cell.data_type == cell.TYPE_STRING:
-                tag(doc, 'v', body = '%s' % string_table[value])
+                tag(doc, 'v', body='%s' % string_table[value])
             elif cell.data_type == cell.TYPE_FORMULA:
-                tag(doc, 'f', body = '%s' % value[1:])
+                tag(doc, 'f', body='%s' % value[1:])
                 tag(doc, 'v')
             elif cell.data_type == cell.TYPE_NUMERIC:
-                if isinstance(value, long):
-                    func=str
+                if isinstance(value, (long, decimal.Decimal)):
+                    func = str
                 else:
-                    func=repr
-                tag(doc, 'v', body = func(value))
+                    func = repr
+                tag(doc, 'v', body=func(value))
             elif cell.data_type == cell.TYPE_BOOL:
-                tag(doc, 'v', body = '%d' % value)
+                tag(doc, 'v', body='%d' % value)
             else:
-                tag(doc, 'v', body = '%s' % value)
+                tag(doc, 'v', body='%s' % value)
             end_tag(doc, 'c')
         end_tag(doc, 'row')
     end_tag(doc, 'sheetData')
